package org.globus.transfer.reliable.service.test.connection;

import junit.framework.TestCase;
import org.globus.rft.generated.RFTOptionsType;
import org.globus.transfer.reliable.service.test.TestConfig;
import org.globus.transfer.reliable.service.cache.ConnectionParameter;

public class ConnectionParameterTest extends TestCase {
   
    private RFTOptionsType rftOptions1;
    private RFTOptionsType rftOptions2;
    private ConnectionParameter params1;
    private ConnectionParameter params2;
    private ConnectionParameter params3;

    protected void setUp() throws Exception {
        
        super.setUp();
        this.rftOptions1 = new RFTOptionsType();
        rftOptions1.setDcau(new Boolean(false));
        this.rftOptions2 = new RFTOptionsType();
        rftOptions2.setDcau(new Boolean(true));

        this.params1 = new ConnectionParameter(
            TestConfig.sourceHost, TestConfig.sourcePort,
            TestConfig.sourcePath, TestConfig.destinationHost,
            TestConfig.destPort, TestConfig.destPath, TestConfig.subject,
            rftOptions1);
        this.params2 = new ConnectionParameter(
            TestConfig.sourceHost, TestConfig.sourcePort,
            TestConfig.sourcePath, TestConfig.destinationHost,
            TestConfig.destPort, TestConfig.destPath, TestConfig.subject,
            rftOptions2);
        this.params3 = new ConnectionParameter(
            TestConfig.sourceHost, TestConfig.sourcePort,
            TestConfig.sourcePath, TestConfig.subject,
            rftOptions2);
        TestConfig.printConfig();
    }

    public void testGetType() {
        
        assertTrue(params1.getType() == ConnectionParameter.DOUBLE_TYPE);
        assertTrue(params3.getType() == ConnectionParameter.SINGLE_TYPE);
    }

    public void testGetHashCode() {

        // this is a very simple test of the hashcode!
        assertTrue(params1.hashCode() != params2.hashCode());
        assertTrue(params1.hashCode() != params3.hashCode());
        assertTrue(params2.hashCode() != params3.hashCode());
    }

    public void testGetDestinationHost() {
        assertTrue(params1.getDestinationHost().equals(
            TestConfig.destinationHost));
    }

    public void testGetDestinationPath() {
        assertTrue(params1.getDestinationPath().equals(TestConfig.destPath));
    }

    public void testGetDestinationPort() {
        assertTrue(params1.getDestinationPort() == TestConfig.destPort);
    }

    public void testGetSourceHost() {
        assertTrue(params1.getSourceHost().equals(TestConfig.sourceHost));
    }

    public void testGetSourcePath() {
        assertTrue(params1.getSourcePath().equals(TestConfig.sourcePath));
    }

    public void testGetSourcePort() {
        assertTrue(params1.getSourcePort() == TestConfig.sourcePort);
    }

    public void testGetUserDN() {
        assertTrue(params1.getUserDN().equals(TestConfig.subject));
    }

    public void testGetRftOptions() {
        assertTrue(params1.getRFTOptions().equals(this.rftOptions1));
    }

}
